Module platform

Module platform 

Functions

check_status
Probes a path to determine its current mount/connection status.
inspect_path
Inspects a filesystem path and returns detailed information about it.
mount_path
Connects (maps) a network share to a local drive letter on Windows.
try_mount_if_needed
Attempts to mount a drive/share if the given path is not currently available.